A2dpSink: Accept Absolute volume from non-streaming source.

When non-streaming source device sent absolute volume with some
value(x%), sink device is not accepting with same value(x%), it is
accepting with value(y%) which it has currently streaming(y%) and
also sent changed rsp with same(y%). Due to this, non-streaming
source device is continuousely sending absolute volume with +1/-1
for matching and till '0', if streaming would be on 100% with active
streaming device.

This change would take care of accepting the non-streaming source
device sent absolute volume(x%) at sink end, and respond with Sink
volume(y%).

CRs-Fixed: 2675421
Change-Id: Ib94ad60bbf4de27f2216c4ffb42df26a0c0ce476
diff --git a/src/com/android/bluetooth/avrcpcontroller/AvrcpControllerStateMachine.java b/src/com/android/bluetooth/avrcpcontroller/AvrcpControllerStateMachine.java
index 92a67db..9f61b4b 100644
--- a/src/com/android/bluetooth/avrcpcontroller/AvrcpControllerStateMachine.java
+++ b/src/com/android/bluetooth/avrcpcontroller/AvrcpControllerStateMachine.java
@@ -845,14 +845,13 @@
         int currIndex = mAudioManager.getStreamVolume(AudioManager.STREAM_MUSIC);
 
         /* If SetAbsVolume Control Cmd is received from non-Streaming device then the
          * requested volume level will not be set fot rendering and current Abs vol level
          *  at DUT (sink: rendering device) will be sent in response. */
         Log.d(TAG, "Streaming device: " + A2dpSinkService.getCurrentStreamingDevice()
                 + " Device: " + mDevice + " absVol: " + absVol + " label: " + label);
         if (!mDevice.equals(A2dpSinkService.getCurrentStreamingDevice())) {
-            absVol = (currIndex * ABS_VOL_BASE) / maxVolume;
             Log.w(TAG, "Volume change request came from non-streaming device," +
-                    "respond with current absVol: " + absVol);
+                    "respond with accepted absVol: " + absVol + "at Sink");
             AvrcpControllerService.sendAbsVolRspNative(mRemoteDevice.getBluetoothAddress(), absVol,
                 label);
             int percentageVol = getVolumePercentage();
@@ -845,14 +845,13 @@
 
         /* If SetAbsVolume Control Cmd is received from non-Streaming device then the
-         * requested volume level will not be set fot rendering and current Abs vol level
-         *  at DUT (sink: rendering device) will be sent in response. */
+         * requested volume level would be accepted at SINK device, and current Abs vol level
+         * at DUT (sink: rendering device) will be sent in changed response. */
         Log.d(TAG, "Streaming device: " + A2dpSinkService.getCurrentStreamingDevice()
                 + " Device: " + mDevice + " absVol: " + absVol + " label: " + label);